///////////////////////////////////////////////////////////////////////////////
//
// Copyright: Kevin Krammer <kevin.krammer@gmx.at>, 2004
//
///////////////////////////////////////////////////////////////////////////////
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as
//   published by the Free Software Foundation; either version 2 of the
//   License, or (at your option) any later version.
//
///////////////////////////////////////////////////////////////////////////////

// Qt includes
#include <qfileinfo.h>
#include <qfiledialog.h>
#include <qlineedit.h>
#include <qsound.h>
#include <qspinbox.h>

// local includes
#include "qsoundtest.h"

///////////////////////////////////////////////////////////////////////////////

QSoundTest::QSoundTest(QWidget* parent)
    : QSoundTestBase(parent, "qsoundtest"),
      m_sound(0)
{
}

///////////////////////////////////////////////////////////////////////////////

QSoundTest::~QSoundTest()
{
    delete m_sound;
}

///////////////////////////////////////////////////////////////////////////////

void QSoundTest::slotBrowse()
{
    QString filename =
        QFileDialog::getOpenFileName(QString::null,
                                     tr("Sound files (*.wav)"), this);

    if (!filename.isNull())
        m_edFile->setText(filename);
}

///////////////////////////////////////////////////////////////////////////////

void QSoundTest::slotPlay()
{
    QString filename = m_edFile->text();
    if (filename.isEmpty()) return;

    QFileInfo fileInfo(filename);
    if (!fileInfo.exists() || !fileInfo.isReadable()) return;

    if (m_sound != 0)
        slotStop();

    m_sound = new QSound(filename);

    m_sound->setLoops(m_sbLoops->value());

    m_sound->play();
}

///////////////////////////////////////////////////////////////////////////////

void QSoundTest::slotStop()
{
    if (m_sound == 0) return;

    m_sound->stop();

    delete m_sound;
    m_sound = 0;
}

// end of file
